@@ -62,6 +62,7 @@ SETTINGS_DEFAULTS = {
     },
     'policy:remote': {
         'fake_user': None,
+        'header': None,
         'login_url': None,
         'logout_url': None,
     },
@@ -89,6 +90,7 @@ SETTINGS_RULES = {
     ],
     'policy:remote': [
         ('fake_user', (str, NoneType), 'fake_user must be a string designating a username'),
+        ('header', (str, NoneType), 'header must be a string designating a HTTP header'),
         ('login_url', (str, NoneType), 'login_url must be a string designating a valid url'),
         ('logout_url', (str, NoneType), 'logout_url must be a string designating a valid url'),
     ],
@@ -289,19 +291,16 @@ class MultiSecurityPolicy:
         return self.cookie.remember(request, username, **kw)
 
 
-# pylint: disable=unused-argument
 def auth_fake_user_tween_factory(handler, registry):
     """
     Tween that adds a fake user to environ to simulate remote user based
     authentication.
     """
 
-    def auth_fake_user_tween(request):
-        # Get fake user from settings
-        registry = request.registry
-        settings = registry.settings
-        username = settings['auth']['policy:remote']['fake_user']
+    settings = registry.settings
+    username = settings['auth']['policy:remote']['fake_user']
 
+    def auth_fake_user_tween(request):
         # Add fake user as REMOTE_USER if requested
         environ = request.environ
         environ['REMOTE_USER'] = username
@@ -314,6 +313,24 @@ def auth_fake_user_tween_factory(handler, registry):
     return auth_fake_user_tween
 
 
+def auth_header_user_tween_factory(handler, registry):
+    """
+    Tween that adds remote user from header
+    This is useful when application is behind a proxy that handles authentication
+    """
+
+    settings = registry.settings
+    header = settings['auth']['policy:remote']['header']
+
+    def auth_header_user_tween(request):
+        if header in request.headers:
+            request.environ['REMOTE_USER'] = request.headers[header]
+
+        return handler(request)
+
+    return auth_header_user_tween
+
+
 def check_credentials(username, password, request):
     """ Check extracted credential using configured mode """
 
@@ -467,10 +484,21 @@ def includeme(config):
     settings = parse_settings(settings)
 
     # Add fake user tween if needed
-    if 'remote' in settings['auth']['policies'] and settings['policy:remote']['fake_user'] is not None:
-        log.warning('[AUTH] POLICY `remote` IS ENABLED WITH `fake_user` SET TO `%s`, USER `%s` WILL BE AUTOMATICALLY CONNECTED WITHOUT ANY AUTHENTICATION, THIS IS VERY DANGEROUS !!!', settings['policy:remote']['fake_user'], settings['policy:remote']['fake_user'])
+    if 'remote' in settings['auth']['policies']:
+        if settings['policy:remote']['fake_user'] is not None:
+            log.warning(
+                '[AUTH] POLICY `remote` IS ENABLED WITH `fake_user` SET TO `%s`, USER `%s` WILL BE AUTOMATICALLY CONNECTED WITHOUT ANY AUTHENTICATION, THIS IS VERY DANGEROUS !!!',
+                settings['policy:remote']['fake_user'],
+                settings['policy:remote']['fake_user']
+            )
+            config.add_tween('pyramid_helpers.auth.auth_fake_user_tween_factory')
 
-        config.add_tween('pyramid_helpers.auth.auth_fake_user_tween_factory')
+        if settings['policy:remote']['header'] is not None:
+            log.warning(
+                '[AUTH] POLICY `remote` IS ENABLED WITH `header` SET TO `%s`, UNLESS THE APPLICATION IS BEHIND A PROXY THAT MANAGES THIS HEADER, THIS IS VERY DANGEROUS !!!',
+                settings['policy:remote']['header']
+            )
+            config.add_tween('pyramid_helpers.auth.auth_header_user_tween_factory')
 
     # Set security policy
     config.set_security_policy(MultiSecurityPolicy(
