@@ -186,7 +186,7 @@ class Form:
 
         request = self.state.request
         session = request.session
-        _ = request.translate
+        translate = request.translate
 
         # Ensure HTTP method is the one that is expected
         if request.method not in HTTP_METHODS[self.method]:
@@ -204,7 +204,7 @@ class Form:
                 self.params = request.json_body
             except JSONDecodeError:
                 # Invalid JSON content
-                self.errors = dict(_content=_('Invalid JSON content'))
+                self.errors = dict(_content=translate('Invalid JSON content'))
                 self.params = {}
                 self.valid = False
                 return False
@@ -228,7 +228,7 @@ class Form:
 
         if self.csrf_protect and self.csrf_token != decoded.get('_csrf_token'):
             # Invalid CSRF token
-            self.errors = dict(_csrf_token=_('Invalid CSRF token'))
+            self.errors = dict(_csrf_token=translate('Invalid CSRF token'))
             self.result = {}
             self.decoded = decoded
             self.encoded = variable_encode(decoded)
