@@ -40,7 +40,7 @@ def csv_renderer_factory(info):
 
     def _render(value, system):
         request = system.get('request')
-        _ = request.translate
+        translate = request.translate
 
         # Get parameters
         encoding = value.pop('encoding', 'utf-8')
@@ -56,7 +56,7 @@ def csv_renderer_factory(info):
 
         except Exception as exc:
             log.exception('Could not convert view response to CSV')
-            raise HTTPInternalServerError(explanation=_('Could not convert view response to CSV')) from exc
+            raise HTTPInternalServerError(detail=translate('Could not convert view response to CSV')) from exc
 
         # Set content type
         request.response.content_type = 'text/csv; charset="{0}"'.format(encoding)
