@@ -31,6 +31,7 @@ import logging
 import os
 import random
 import string
+import warnings
 
 from decorator import decorator
 import pytz
@@ -46,6 +47,24 @@ TIMEZONE = 'Europe/Paris'
 log = logging.getLogger(__name__)
 
 
+def deprecated(old_name, new_func, new_name=None):
+    """ Display a deprecation warning when function is called """
+
+    def wrapper(*args, **kwargs):
+        warnings.warn(
+            '`{0}()` is deprecated and will be removed soon; use `{1}()'.format(wrapper.__old_name__, wrapper.__new_name__),
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return wrapper.__new_func__(*args, **kwargs)
+
+    wrapper.__old_name__ = old_name
+    wrapper.__new_func__ = new_func
+    wrapper.__new_name__ = new_name or new_func.__name__
+
+    return wrapper
+
+
 def request_cache():
     """
     Cache decorator
